@@ -74,7 +74,11 @@ func runInit(sh, command string) {
 		log.Enable(plain)
 	}
 
-	cache.Init(sh, cache.NewSession, cache.Persist)
+	if sh == "powershell" {
+		sh = shell.PWSH
+	}
+
+	initCache(sh)
 
 	cfg := config.Load(configFlag, false)
 
@@ -161,3 +165,12 @@ func getFullCommand(cmd *cobra.Command, args []string) string {
 
 	return cmdPath
 }
+
+func initCache(sh string) {
+	if !printOutput && eval && sh == shell.PWSH {
+		cache.Init(sh)
+		return
+	}
+
+	cache.Init(sh, cache.NewSession, cache.Persist)
+}
