@@ -36,6 +36,13 @@ var upgradeCmd = &cobra.Command{
 			log.Enable(plain)
 		}
 
+		if upgrade.IsPackagedInstallation() {
+			msg := "upgrade is not supported when installed as a MSIX package"
+			log.Debug(msg)
+			fmt.Printf("\n  ❌ %s\n\n", msg)
+			return
+		}
+
 		supportedPlatforms := []string{
 			runtime.WINDOWS,
 			runtime.DARWIN,
@@ -54,18 +61,23 @@ var upgradeCmd = &cobra.Command{
 			Debug: debug,
 		})
 
-		cache.Init(sh, true)
+		cache.Init(sh, cache.Persist)
+
+		if _, OK := cache.Get[string](cache.Device, upgrade.CACHEKEY); OK {
+			log.Debug("upgrade check already performed recently, skipping")
+			return
+		}
 
 		terminal.Init(sh)
 		fmt.Print(terminal.StartProgress())
 
-		cfg := config.Load(configFlag, false)
+		cfg := config.Get(configFlag, false)
 
 		defer func() {
 			fmt.Print(terminal.StopProgress())
 
 			// always reset the cache key so we respect the interval no matter what the outcome
-			cache.Set(cache.Device, upgrade.CACHEKEY, "", cfg.Upgrade.Interval)
+			cache.Set(cache.Device, upgrade.CACHEKEY, "true", cfg.Upgrade.Interval)
 
 			cache.Close()
 
@@ -93,6 +105,8 @@ var upgradeCmd = &cobra.Command{
 			return
 		}
 
+		log.Debugf("current version: v%s, latest version: v%s", build.Version, latest)
+
 		if force {
 			log.Debug("forced upgrade")
 			exitcode = executeUpgrade(cfg.Upgrade)
@@ -107,9 +121,12 @@ var upgradeCmd = &cobra.Command{
 		}
 
 		if build.Version != latest {
+			log.Debug("upgrade available")
 			exitcode = executeUpgrade(cfg.Upgrade)
 			return
 		}
+
+		log.Debug("already on the latest version")
 	},
 }
 
