@@ -1,13 +1,7 @@
 package segments
 
-import (
-	"github.com/jandedobbeleer/oh-my-posh/src/properties"
-	"github.com/jandedobbeleer/oh-my-posh/src/runtime"
-)
-
 type Helm struct {
-	props properties.Properties
-	env   runtime.Environment
+	Base
 
 	Version string
 }
@@ -34,11 +28,6 @@ func (h *Helm) Template() string {
 	return " Helm {{.Version}}"
 }
 
-func (h *Helm) Init(props properties.Properties, env runtime.Environment) {
-	h.props = props
-	h.env = env
-}
-
 func (h *Helm) getVersion() bool {
 	cmd := "helm"
 	if !h.env.HasCommand(cmd) {
